@@ -39,8 +39,8 @@ api_list = [
     ("Nekos.life", None, "https://github.com/Nekos-life/nekos.py", False),
     ("NekoBot", apis.NekoBotAPI, "https://docs.nekobot.xyz/", True),
     ("Neko-love", apis.NekoLoveAPI, "https://docs.neko-love.xyz/", True),
-    ("Nekos.moe", None, "https://docs.nekos.moe/", False),
-    ("Nekos.best", None, "https://docs.nekos.best/", False),
+    ("Nekos.moe", apis.NekosMoeAPI, "https://docs.nekos.moe/", True),
+    ("Nekos.best", apis.NekosBest, "https://docs.nekos.best/", True),
     ("Shikimori", None, "https://shikimori.one/api/doc", False),
     ("Mangadex", None, "https://api.mangadex.org/docs.html", False),
     ("Danbooru", None, "https://danbooru.donmai.us/wiki_pages/help:api", False),
